<?php

namespace Drupal\disable_ui\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Checks whether the current user has permission to access non-API routes.
 */
class DisableUiAccessCheck implements AccessInterface {

  /**
   * The name of the permission users must have to access non-API routes.
   */
  protected const ACCESS_PERMISSION = 'access ui route';

  /**
   * Checks access for non-API routes.
   *
   * Access is allowed if the user has our permission or if the access route
   * being checked is not the route of the main request (e.g. access checks
   * when generating menu links).
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The account being checked.
   * @param \Symfony\Component\HttpFoundation\Request|null $request
   *   Optional, a request. Only supplied when checking the incoming request.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account, ?Request $request = NULL): AccessResultInterface {
    // See \Drupal\Core\Access\AccessManagerInterface::check(), the $request
    // parameter should only be supplied when checking the incoming request,
    // if we do not receive the request object we can assume that we are
    // checking a route while generating the page.
    $isNotMainRequest = AccessResult::allowedIf(is_null($request));
    return AccessResult::allowedIfHasPermission($account, static::ACCESS_PERMISSION)
      ->orIf($isNotMainRequest);
  }

}
