<?php

namespace Drupal\Tests\disable_ui\Functional;

use Drupal\Component\Serialization\Json;

/**
 * Test basic disabled routes functionality.
 *
 * @group disable_ui
 */
class DisabledRoutesTest extends DisableUiFunctionalTestBase {

  /**
   * Test content routes are disabled without the appropriate permission.
   */
  public function testDisableUiRoutes() {
    // Verify that node pages are inaccessible to anonymous users.
    foreach ($this->nodes as $node) {
      $this->drupalGet($node->toUrl());
      $this->assertSession()->statusCodeEquals(403);
    }

    // Verify that custom route is inaccessible to anonymous users.
    $this->drupalGet('/disable-ui-test/custom-route-disabled');
    $this->assertSession()->statusCodeEquals(403);

    // Verify that node pages are accessible to the user with the correct
    // permission.
    $this->drupalLogin($this->user);
    foreach ($this->nodes as $node) {
      $this->drupalGet($node->toUrl());
      $this->assertSession()->statusCodeEquals(200);
      $this->assertSession()->titleEquals($node->label() . ' | Drupal');
    }

    // Verify that custom route is accessible to users with the correct
    // permission.
    $this->drupalGet('/disable-ui-test/custom-route-disabled');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContainsOnce('Custom route that should be disabled without permission');
  }

  /**
   * Test default UI route exclusions.
   */
  public function testUiRouteExclusions() {
    // Verify that login and logout work using both one-time login links and
    // the login form.
    $this->useOneTimeLoginLinks = TRUE;
    $this->drupalLogin($this->user);
    $this->drupalLogout();

    $this->useOneTimeLoginLinks = FALSE;
    $this->drupalLogin($this->user);
    $this->drupalLogout();

    // Access default route exclusions as anonymous user.
    $paths = [
      '/user/password',
      '/session/token',
    ];
    foreach ($paths as $path) {
      $this->drupalGet($path);
      $this->assertSession()->statusCodeEquals(200);
    }

    // Test exclusion for custom route based on _format set to json.
    $content = Json::decode($this->drupalGet('/disable-ui-test/excluded-by-format'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertEquals($content['test'], 'JSON format route is excluded');

    // Test exclusion using hook_disable_ui_route_exclusions().
    $this->drupalGet('/disable-ui-test/excluded-by-hook');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Custom route that should be excluded with hook_disable_ui_route_exclusions');
  }

}
