<?php

namespace Drupal\Tests\disable_ui\Functional;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Url;

/**
 * Test JSON:API routes.
 *
 * @group disable_ui
 */
class JsonApiRoutesTest extends DisableUiFunctionalTestBase {

  /**
   * Modules list.
   *
   * @var array
   */
  protected static $modules = [
    'jsonapi',
    'serialization',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Rebuild router to pick up JSON:API routes.
    \Drupal::service('router.builder')->rebuild();
  }

  /**
   * Test default JSON:API route exclusions.
   */
  public function testJsonApiExclusions() {
    // Load the JSON:API root listing, iterate through all
    // exposed endpoints and check they are accessible.
    $content = Json::decode($this->drupalGet('/jsonapi'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertGreaterThan(1, count($content['links']));
    foreach ($content['links'] as $link) {
      $this->drupalGet($link['href']);
      $this->assertSession()->statusCodeEquals(200);
    }

    // Check specific JSON:API paths for our test nodes.
    foreach ($this->nodes as $node) {
      $url = Url::fromRoute('jsonapi.node--page.individual', ['entity' => $node->uuid()]);
      $content = JSON::decode($this->drupalGet($url));
      $this->assertSession()->statusCodeEquals(200);
      $this->assertEquals($content['data']['attributes']['title'], $node->label());
    }
  }

}
