<?php

namespace Drupal\Tests\disable_ui\Functional;

use Drupal\Component\Serialization\Json;
use Drupal\menu_link_content\Entity\MenuLinkContent;
use Drupal\system\Entity\Menu;

/**
 * Test menu linkset route.
 *
 * @group disable_ui
 */
class MenuLinksetTest extends DisableUiFunctionalTestBase {

  /**
   * The menu links.
   *
   * @var \Drupal\menu_link_content\Entity\MenuLinkContent[]
   */
  protected $menuLinks = [];

  /**
   * Modules list.
   *
   * @var array
   */
  protected static $modules = [
    'menu_link_content',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Create test menu.
    Menu::create([
      'id' => 'test',
      'label' => 'Test menu',
      'description' => 'Test description',
    ])->save();

    // Add menu content links for each of the created nodes.
    foreach ($this->nodes as $delta => $node) {
      $menuLink = MenuLinkContent::create([
        'title' => $node->label(),
        'provider' => 'menu_link_content',
        'menu_name' => 'test',
        'link' => ['uri' => 'internal:/node/' . $node->id()],
        'weight' => $delta,
      ]);
      $menuLink->save();
      $this->menuLinks[] = $menuLink;
    }

    // Enable menu linkset endpoint.
    $featureFlagsConfig = $this->config('system.feature_flags');
    $featureFlagsConfig->set('linkset_endpoint', TRUE);
    $featureFlagsConfig->save();

    // Rebuild router to pick up linkset routes.
    \Drupal::service('router.builder')->rebuild();
  }

  /**
   * Test menu linkset API.
   */
  public function testMenuLinkset() {
    // Load main menu linkset as anonymous user.
    $content = JSON::decode($this->drupalGet('/system/menu/test/linkset'));
    $this->assertSession()->statusCodeEquals(200);

    // Check all the expected links are there.
    foreach ($content['linkset'][0]['item'] as $delta => $link) {
      $this->assertEquals($this->menuLinks[$delta]->label(), $link['title']);
    }
  }

}
