<?php

namespace Drupal\Tests\disable_ui\Functional;

use Drupal\Component\Serialization\Json;
use Drupal\rest\Entity\RestResourceConfig;
use Drupal\rest\RestResourceConfigInterface;

/**
 * Test REST routes.
 *
 * @group disable_ui
 */
class RestRoutesTest extends DisableUiFunctionalTestBase {

  /**
   * Modules list.
   *
   * @var array
   */
  protected static $modules = [
    'rest',
    'serialization',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Set up basic REST resource for getting nodes.
    RestResourceConfig::create([
      'id' => 'entity.node',
      'plugin_id' => 'entity:node',
      'granularity' => RestResourceConfigInterface::RESOURCE_GRANULARITY,
      'configuration' => [
        'methods' => ['GET'],
        'formats' => ['json'],
        'authentication' => ['cookie'],
      ],
      'status' => TRUE,
    ])->save();

    // Rebuild router to pick up REST routes.
    \Drupal::service('router.builder')->rebuild();
  }

  /**
   * Test default REST route exclusions.
   */
  public function testRestExclusions() {
    // Load each node through the default JSON format.
    foreach ($this->nodes as $node) {
      $url = $node->toUrl('canonical', ['query' => ['_format' => 'json']]);
      $content = JSON::decode($this->drupalGet($url));
      $this->assertSession()->statusCodeEquals(200);
      $this->assertEquals($content['title'][0]['value'], $node->label());
    }
  }

}
